]> Shamusworld >> Repos - rmac/blobdiff - token.h
Fix for bug #51. Apparently 10 tokens weren't enough for modern programming!
[rmac] / token.h
diff --git a/token.h b/token.h
index 501f1eaaca237be8c6dfec97c230c6bccbba4789..3d3ea22c017b4f1a5c7fc144c1e83818a6d5ed52 100644 (file)
--- a/token.h
+++ b/token.h
@@ -111,8 +111,8 @@ IFILE {
 
 #define TOKENSTREAM struct _tokenstream
 TOKENSTREAM {
-       TOKEN token[10];                // 10 ought to be enough for anybody
-       char * string[10];              // same for attached strings
+       TOKEN token[32];                // 32 ought to be enough for anybody (including XiA!)
+       char * string[32];              // same for attached strings
 };
 
 // Information about a macro invocation